@@ -44,17 +44,19 @@ public:
     LanLinkProvider(bool testMode = false);
     ~LanLinkProvider() override;
 
-    QString name() override { return "LanLinkProvider"; }
+    QString name() override { return QStringLiteral("LanLinkProvider"); }
     int priority() override { return PRIORITY_HIGH; }
 
-    void userRequestsPair(const QString &deviceId);
-    void userRequestsUnpair(const QString &deviceId);
-    void incomingPairPackage(DeviceLink* device, const NetworkPackage& np);
+    void userRequestsPair(const QString& deviceId);
+    void userRequestsUnpair(const QString& deviceId);
+    void incomingPairPacket(DeviceLink* device, const NetworkPacket& np);
 
     static void configureSslSocket(QSslSocket* socket, const QString& deviceId, bool isDeviceTrusted);
     static void configureSocket(QSslSocket* socket);
 
-    const static quint16 PORT = 1716;
+    const static quint16 UDP_PORT = 1716;
+    const static quint16 MIN_TCP_PORT = 1716;
+    const static quint16 MAX_TCP_PORT = 1764;
 
 public Q_SLOTS:
     void onNetworkChange() override;
@@ -75,24 +77,24 @@ private Q_SLOTS:
 private:
     LanPairingHandler* createPairingHandler(DeviceLink* link);
 
-    void onNetworkConfigurationChanged(const QNetworkConfiguration &config);
-    void addLink(const QString& deviceId, QSslSocket* socket, NetworkPackage* receivedPackage, LanDeviceLink::ConnectionStarted connectionOrigin);
+    void onNetworkConfigurationChanged(const QNetworkConfiguration& config);
+    void addLink(const QString& deviceId, QSslSocket* socket, NetworkPacket* receivedPacket, LanDeviceLink::ConnectionStarted connectionOrigin);
 
-    Server* mServer;
-    QUdpSocket mUdpSocket;
-    quint16 mTcpPort;
+    Server* m_server;
+    QUdpSocket m_udpSocket;
+    quint16 m_tcpPort;
 
-    QMap<QString, LanDeviceLink*> mLinks;
-    QMap<QString, LanPairingHandler*> mPairingHandlers;
+    QMap<QString, LanDeviceLink*> m_links;
+    QMap<QString, LanPairingHandler*> m_pairingHandlers;
 
     struct PendingConnect {
-        NetworkPackage* np;
+        NetworkPacket* np;
         QHostAddress sender;
     };
-    QMap<QSslSocket*, PendingConnect> receivedIdentityPackages;
+    QMap<QSslSocket*, PendingConnect> m_receivedIdentityPackets;
     QNetworkConfiguration m_lastConfig;
-    const bool mTestMode;
-    QTimer combineBroadcastsTimer;
+    const bool m_testMode;
+    QTimer m_combineBroadcastsTimer;
 };
 
 #endif
