@@ -25,21 +25,19 @@
 #include "kdeconnectconfig.h"
 #include "landevicelink.h"
 #include "lanpairinghandler.h"
-#include "networkpackagetypes.h"
+#include "networkpackettypes.h"
 
 LanPairingHandler::LanPairingHandler(DeviceLink* deviceLink)
     : PairingHandler(deviceLink)
     , m_status(NotPaired)
 {
     m_pairingTimeout.setSingleShot(true);
-    m_pairingTimeout.setInterval(30 * 1000);  //30 seconds of timeout
+    m_pairingTimeout.setInterval(pairingTimeoutMsec());
     connect(&m_pairingTimeout, &QTimer::timeout, this, &LanPairingHandler::pairingTimeout);
 }
 
-void LanPairingHandler::packageReceived(const NetworkPackage& np)
+void LanPairingHandler::packetReceived(const NetworkPacket& np)
 {
-    m_pairingTimeout.stop();
-
     bool wantsPair = np.get<bool>(QStringLiteral("pair"));
 
     if (wantsPair) {
@@ -57,7 +55,6 @@ void LanPairingHandler::packageReceived(const NetworkPackage& np)
                 return;
             }
 
-            Daemon::instance()->askPairingConfirmation(this);
             setInternalPairStatus(RequestedByPeer);
         }
 
@@ -65,44 +62,36 @@ void LanPairingHandler::packageReceived(const NetworkPackage& np)
 
         qCDebug(KDECONNECT_CORE) << "Unpair request";
 
-        setInternalPairStatus(NotPaired);
          if (isPairRequested()) {
             Q_EMIT pairingError(i18n("Canceled by other peer"));
         }
+        setInternalPairStatus(NotPaired);
     }
 }
 
 bool LanPairingHandler::requestPairing()
 {
-    switch (m_status) {
-        case Paired:
-            Q_EMIT pairingError(i18n("%1: Already paired", deviceLink()->name()));
-            return false;
-        case Requested:
-            Q_EMIT pairingError(i18n("%1: Pairing already requested for this device", deviceLink()->name()));
-            return false;
-        case RequestedByPeer:
-            qCDebug(KDECONNECT_CORE) << deviceLink()->name() << " : Pairing already started by the other end, accepting their request.";
-            acceptPairing();
-            return false;
-        case NotPaired:
-            ;
+    if (m_status == Paired) {
+        Q_EMIT pairingError(i18n("%1: Already paired", deviceLink()->name()));
+        return false;
+    }
+    if (m_status == RequestedByPeer) {
+        qCDebug(KDECONNECT_CORE) << deviceLink()->name() << ": Pairing already started by the other end, accepting their request.";
+        return acceptPairing();
     }
 
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", true}});
-    const bool success = deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{"pair", true}});
+    const bool success = deviceLink()->sendPacket(np);
     if (success) {
         setInternalPairStatus(Requested);
-        m_pairingTimeout.start();
     }
     return success;
 }
 
 bool LanPairingHandler::acceptPairing()
 {
-    m_pairingTimeout.stop(); // Just in case it is started
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", true}});
-    bool success = deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{"pair", true}});
+    bool success = deviceLink()->sendPacket(np);
     if (success) {
         setInternalPairStatus(Paired);
     }
@@ -111,27 +100,39 @@ bool LanPairingHandler::acceptPairing()
 
 void LanPairingHandler::rejectPairing()
 {
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", false}});
-    deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{"pair", false}});
+    deviceLink()->sendPacket(np);
     setInternalPairStatus(NotPaired);
 }
 
 void LanPairingHandler::unpair() {
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", false}});
-    deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{"pair", false}});
+    deviceLink()->sendPacket(np);
     setInternalPairStatus(NotPaired);
 }
 
 void LanPairingHandler::pairingTimeout()
 {
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", false}});
-    deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{"pair", false}});
+    deviceLink()->sendPacket(np);
     setInternalPairStatus(NotPaired); //Will emit the change as well
     Q_EMIT pairingError(i18n("Timed out"));
 }
 
 void LanPairingHandler::setInternalPairStatus(LanPairingHandler::InternalPairStatus status)
 {
+    if (status == Requested || status == RequestedByPeer) {
+        m_pairingTimeout.start();
+    } else {
+        m_pairingTimeout.stop();
+    }
+
+    if (m_status == RequestedByPeer && (status == NotPaired || status == Paired)) {
+        Q_EMIT deviceLink()->pairingRequestExpired(this);
+    } else if (status == RequestedByPeer) {
+        Q_EMIT deviceLink()->pairingRequest(this);
+    }
+
     m_status = status;
     if (status == Paired) {
         deviceLink()->setPairStatus(DeviceLink::Paired);
