@@ -21,108 +21,115 @@
 #include "daemon.h"
 
 #include <QDBusConnection>
+#include <QDBusMetaType>
 #include <QNetworkAccessManager>
 #include <QDebug>
 #include <QPointer>
 
 #include "core_debug.h"
 #include "kdeconnectconfig.h"
-#include "networkpackage.h"
+#include "networkpacket.h"
+
+#ifdef KDECONNECT_BLUETOOTH
+    #include "backends/bluetooth/bluetoothlinkprovider.h"
+#endif
+
 #include "backends/lan/lanlinkprovider.h"
 #include "backends/loopback/loopbacklinkprovider.h"
 #include "device.h"
 #include "backends/devicelink.h"
 #include "backends/linkprovider.h"
 
-Q_GLOBAL_STATIC(Daemon*, s_instance)
+static Daemon* s_instance = nullptr;
 
 struct DaemonPrivate
 {
     //Different ways to find devices and connect to them
-    QSet<LinkProvider*> mLinkProviders;
+    QSet<LinkProvider*> m_linkProviders;
 
     //Every known device
-    QMap<QString, Device*> mDevices;
+    QMap<QString, Device*> m_devices;
 
-    QSet<QString> mDiscoveryModeAcquisitions;
+    QSet<QString> m_discoveryModeAcquisitions;
 };
 
 Daemon* Daemon::instance()
 {
-    Q_ASSERT(s_instance.exists());
-    return *s_instance;
+    Q_ASSERT(s_instance != nullptr);
+    return s_instance;
 }
 
-Daemon::Daemon(QObject *parent, bool testMode)
+Daemon::Daemon(QObject* parent, bool testMode)
     : QObject(parent)
     , d(new DaemonPrivate)
 {
-    Q_ASSERT(!s_instance.exists());
-    *s_instance = this;
+    Q_ASSERT(!s_instance);
+    s_instance = this;
     qCDebug(KDECONNECT_CORE) << "KdeConnect daemon starting";
 
     //Load backends
     if (testMode)
-        d->mLinkProviders.insert(new LoopbackLinkProvider());
-    else
-        d->mLinkProviders.insert(new LanLinkProvider());
+        d->m_linkProviders.insert(new LoopbackLinkProvider());
+    else {
+        d->m_linkProviders.insert(new LanLinkProvider());
+        #ifdef KDECONNECT_BLUETOOTH
+            d->m_linkProviders.insert(new BluetoothLinkProvider());
+        #endif
+    }
 
     //Read remebered paired devices
     const QStringList& list = KdeConnectConfig::instance()->trustedDevices();
-    Q_FOREACH (const QString& id, list) {
-        Device* device = new Device(this, id);
-        connect(device, SIGNAL(reachableStatusChanged()), this, SLOT(onDeviceStatusChanged()));
-        connect(device, SIGNAL(trustedChanged(bool)), this, SLOT(onDeviceStatusChanged()));
-        d->mDevices[id] = device;
-        Q_EMIT deviceAdded(id);
+    for (const QString& id : list) {
+        addDevice(new Device(this, id));
     }
 
     //Listen to new devices
-    Q_FOREACH (LinkProvider* a, d->mLinkProviders) {
-        connect(a, SIGNAL(onConnectionReceived(NetworkPackage,DeviceLink*)),
-                this, SLOT(onNewDeviceLink(NetworkPackage,DeviceLink*)));
+    for (LinkProvider* a : qAsConst(d->m_linkProviders)) {
+        connect(a, &LinkProvider::onConnectionReceived,
+                this, &Daemon::onNewDeviceLink);
         a->onStart();
     }
 
     //Register on DBus
-    QDBusConnection::sessionBus().registerService("org.kde.kdeconnect");
-    QDBusConnection::sessionBus().registerObject("/modules/kdeconnect", this, QDBusConnection::ExportScriptableContents);
+    qDBusRegisterMetaType< QMap<QString,QString> >();
+    QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.kdeconnect"));
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/modules/kdeconnect"), this, QDBusConnection::ExportScriptableContents);
 
     qCDebug(KDECONNECT_CORE) << "KdeConnect daemon started";
 }
 
-void Daemon::acquireDiscoveryMode(const QString &key)
+void Daemon::acquireDiscoveryMode(const QString& key)
 {
-    bool oldState = d->mDiscoveryModeAcquisitions.isEmpty();
+    bool oldState = d->m_discoveryModeAcquisitions.isEmpty();
 
-    d->mDiscoveryModeAcquisitions.insert(key);
+    d->m_discoveryModeAcquisitions.insert(key);
 
-    if (oldState != d->mDiscoveryModeAcquisitions.isEmpty()) {
+    if (oldState != d->m_discoveryModeAcquisitions.isEmpty()) {
         forceOnNetworkChange();
     }
 }
 
-void Daemon::releaseDiscoveryMode(const QString &key)
+void Daemon::releaseDiscoveryMode(const QString& key)
 {
-    bool oldState = d->mDiscoveryModeAcquisitions.isEmpty();
+    bool oldState = d->m_discoveryModeAcquisitions.isEmpty();
 
-    d->mDiscoveryModeAcquisitions.remove(key);
+    d->m_discoveryModeAcquisitions.remove(key);
 
-    if (oldState != d->mDiscoveryModeAcquisitions.isEmpty()) {
+    if (oldState != d->m_discoveryModeAcquisitions.isEmpty()) {
         cleanDevices();
     }
 }
 
 void Daemon::removeDevice(Device* device)
 {
-    d->mDevices.remove(device->id());
+    d->m_devices.remove(device->id());
     device->deleteLater();
     Q_EMIT deviceRemoved(device->id());
 }
 
 void Daemon::cleanDevices()
 {
-    Q_FOREACH (Device* device, d->mDevices) {
+    for (Device* device : qAsConst(d->m_devices)) {
         if (device->isTrusted()) {
             continue;
         }
@@ -136,15 +143,15 @@ void Daemon::cleanDevices()
 
 void Daemon::forceOnNetworkChange()
 {
-    qCDebug(KDECONNECT_CORE) << "Sending onNetworkChange to " << d->mLinkProviders.size() << " LinkProviders";
-    Q_FOREACH (LinkProvider* a, d->mLinkProviders) {
+    qCDebug(KDECONNECT_CORE) << "Sending onNetworkChange to " << d->m_linkProviders.size() << " LinkProviders";
+    for (LinkProvider* a : qAsConst(d->m_linkProviders)) {
         a->onNetworkChange();
     }
 }
 
 Device*Daemon::getDevice(const QString& deviceId)
 {
-    Q_FOREACH (Device* device, d->mDevices) {
+    for (Device* device : qAsConst(d->m_devices)) {
         if (device->id() == deviceId) {
             return device;
         }
@@ -155,7 +162,7 @@ Device*Daemon::getDevice(const QString& deviceId)
 QStringList Daemon::devices(bool onlyReachable, bool onlyTrusted) const
 {
     QStringList ret;
-    Q_FOREACH (Device* device, d->mDevices) {
+    for (Device* device : qAsConst(d->m_devices)) {
         if (onlyReachable && !device->isReachable()) continue;
         if (onlyTrusted && !device->isTrusted()) continue;
         ret.append(device->id());
@@ -163,33 +170,40 @@ QStringList Daemon::devices(bool onlyReachable, bool onlyTrusted) const
     return ret;
 }
 
-void Daemon::onNewDeviceLink(const NetworkPackage& identityPackage, DeviceLink* dl)
+QMap<QString, QString> Daemon::deviceNames(bool onlyReachable, bool onlyTrusted) const
 {
-    const QString& id = identityPackage.get<QString>("deviceId");
+    QMap<QString, QString> ret;
+    for (Device* device : qAsConst(d->m_devices)) {
+        if (onlyReachable && !device->isReachable()) continue;
+        if (onlyTrusted && !device->isTrusted()) continue;
+        ret[device->id()] = device->name();
+    }
+    return ret;
+}
+
+void Daemon::onNewDeviceLink(const NetworkPacket& identityPacket, DeviceLink* dl)
+{
+    const QString& id = identityPacket.get<QString>(QStringLiteral("deviceId"));
 
     //qCDebug(KDECONNECT_CORE) << "Device discovered" << id << "via" << dl->provider()->name();
 
-    if (d->mDevices.contains(id)) {
-        qCDebug(KDECONNECT_CORE) << "It is a known device" << identityPackage.get<QString>("deviceName");
-        Device* device = d->mDevices[id];
+    if (d->m_devices.contains(id)) {
+        qCDebug(KDECONNECT_CORE) << "It is a known device" << identityPacket.get<QString>(QStringLiteral("deviceName"));
+        Device* device = d->m_devices[id];
         bool wasReachable = device->isReachable();
-        device->addLink(identityPackage, dl);
+        device->addLink(identityPacket, dl);
         if (!wasReachable) {
             Q_EMIT deviceVisibilityChanged(id, true);
         }
     } else {
-        qCDebug(KDECONNECT_CORE) << "It is a new device" << identityPackage.get<QString>("deviceName");
-        Device* device = new Device(this, identityPackage, dl);
+        qCDebug(KDECONNECT_CORE) << "It is a new device" << identityPacket.get<QString>(QStringLiteral("deviceName"));
+        Device* device = new Device(this, identityPacket, dl);
 
         //we discard the connections that we created but it's not paired.
         if (!isDiscoveringDevices() && !device->isTrusted() && !dl->linkShouldBeKeptAlive()) {
             device->deleteLater();
         } else {
-            connect(device, SIGNAL(reachableStatusChanged()), this, SLOT(onDeviceStatusChanged()));
-            connect(device, SIGNAL(trustedChanged(bool)), this, SLOT(onDeviceStatusChanged()));
-            d->mDevices[id] = device;
-
-            Q_EMIT deviceAdded(id);
+            addDevice(device);
         }
     }
 }
@@ -209,11 +223,12 @@ void Daemon::onDeviceStatusChanged()
 
 }
 
-void Daemon::setAnnouncedName(const QString &name)
+void Daemon::setAnnouncedName(const QString& name)
 {
     qCDebug(KDECONNECT_CORE()) << "Announcing name";
     KdeConnectConfig::instance()->setName(name);
     forceOnNetworkChange();
+    Q_EMIT announcedNameChanged(name);
 }
 
 QString Daemon::announcedName()
@@ -232,24 +247,54 @@ QNetworkAccessManager* Daemon::networkAccessManager()
 
 QList<Device*> Daemon::devicesList() const
 {
-    return d->mDevices.values();
+    return d->m_devices.values();
 }
 
 bool Daemon::isDiscoveringDevices() const
 {
-    return !d->mDiscoveryModeAcquisitions.isEmpty();
+    return !d->m_discoveryModeAcquisitions.isEmpty();
 }
 
-QString Daemon::deviceIdByName(const QString &name) const
+QString Daemon::deviceIdByName(const QString& name) const
 {
-    Q_FOREACH (Device* d, d->mDevices) {
-        if (d->name() == name && d->isTrusted())
-            return d->id();
+    for (Device* device : qAsConst(d->m_devices)) {
+        if (device->name() == name && device->isTrusted())
+            return device->id();
     }
     return {};
 }
 
+void Daemon::addDevice(Device* device)
+{
+    const QString id = device->id();
+    connect(device, &Device::reachableChanged, this, &Daemon::onDeviceStatusChanged);
+    connect(device, &Device::trustedChanged, this, &Daemon::onDeviceStatusChanged);
+    connect(device, &Device::hasPairingRequestsChanged, this, &Daemon::pairingRequestsChanged);
+    connect(device, &Device::hasPairingRequestsChanged, this, [this, device](bool hasPairingRequests) {
+        if (hasPairingRequests)
+            askPairingConfirmation(device);
+    } );
+    d->m_devices[id] = device;
+
+    Q_EMIT deviceAdded(id);
+}
+
+QStringList Daemon::pairingRequests() const
+{
+    QStringList ret;
+    for(Device* dev: d->m_devices) {
+        if (dev->hasPairingRequests())
+            ret += dev->id();
+    }
+    return ret;
+}
+
 Daemon::~Daemon()
 {
 
 }
+
+QString Daemon::selfId() const
+{
+    return KdeConnectConfig::instance()->deviceId();
+}
