@@ -36,8 +36,8 @@ PluginLoader* PluginLoader::instance()
 
 PluginLoader::PluginLoader()
 {
-    QVector<KPluginMetaData> data = KPluginLoader::findPlugins("kdeconnect/");
-    Q_FOREACH (const KPluginMetaData& metadata, data) {
+    const QVector<KPluginMetaData> data = KPluginLoader::findPlugins(QStringLiteral("kdeconnect/"));
+    for (const KPluginMetaData& metadata : data) {
         plugins[metadata.pluginId()] = metadata;
     }
 }
@@ -63,13 +63,13 @@ KdeConnectPlugin* PluginLoader::instantiatePluginForDevice(const QString& plugin
     }
 
     KPluginLoader loader(service.fileName());
-    KPluginFactory *factory = loader.factory();
+    KPluginFactory* factory = loader.factory();
     if (!factory) {
         qCDebug(KDECONNECT_CORE) << "KPluginFactory could not load the plugin:" << service.pluginId() << loader.errorString();
         return ret;
     }
 
-    const QStringList outgoingInterfaces = KPluginMetaData::readStringList(service.rawData(), "X-KdeConnect-OutgoingPackageType");
+    const QStringList outgoingInterfaces = KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-OutgoingPacketType"));
 
     QVariant deviceVariant = QVariant::fromValue<Device*>(device);
 
@@ -86,8 +86,8 @@ KdeConnectPlugin* PluginLoader::instantiatePluginForDevice(const QString& plugin
 QStringList PluginLoader::incomingCapabilities() const
 {
     QSet<QString> ret;
-    Q_FOREACH (const KPluginMetaData& service, plugins) {
-        ret += KPluginMetaData::readStringList(service.rawData(), "X-KdeConnect-SupportedPackageType").toSet();
+    for (const KPluginMetaData& service : qAsConst(plugins)) {
+        ret += KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-SupportedPacketType")).toSet();
     }
     return ret.toList();
 }
@@ -95,8 +95,8 @@ QStringList PluginLoader::incomingCapabilities() const
 QStringList PluginLoader::outgoingCapabilities() const
 {
     QSet<QString> ret;
-    Q_FOREACH (const KPluginMetaData& service, plugins) {
-        ret += KPluginMetaData::readStringList(service.rawData(), "X-KdeConnect-OutgoingPackageType").toSet();
+    for (const KPluginMetaData& service : qAsConst(plugins)) {
+        ret += KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-OutgoingPacketType")).toSet();
     }
     return ret.toList();
 }
@@ -105,9 +105,9 @@ QSet<QString> PluginLoader::pluginsForCapabilities(const QSet<QString>& incoming
 {
     QSet<QString> ret;
 
-    Q_FOREACH (const KPluginMetaData& service, plugins) {
-        const QSet<QString> pluginIncomingCapabilities = KPluginMetaData::readStringList(service.rawData(), "X-KdeConnect-SupportedPackageType").toSet();
-        const QSet<QString> pluginOutgoingCapabilities = KPluginMetaData::readStringList(service.rawData(), "X-KdeConnect-OutgoingPackageType").toSet();
+    for (const KPluginMetaData& service : qAsConst(plugins)) {
+        const QSet<QString> pluginIncomingCapabilities = KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-SupportedPacketType")).toSet();
+        const QSet<QString> pluginOutgoingCapabilities = KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-OutgoingPacketType")).toSet();
 
         bool capabilitiesEmpty = (pluginIncomingCapabilities.isEmpty() && pluginOutgoingCapabilities.isEmpty());
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
