@@ -43,19 +43,19 @@ class MousepadPlugin
     Q_OBJECT
 
 public:
-    explicit MousepadPlugin(QObject *parent, const QVariantList &args);
+    explicit MousepadPlugin(QObject* parent, const QVariantList& args);
     ~MousepadPlugin() override;
 
-    bool receivePackage(const NetworkPackage& np) override;
+    bool receivePacket(const NetworkPacket& np) override;
     void connected() override { }
 
 private:
 #if HAVE_X11
-    bool handlePackageX11(const NetworkPackage& np);
+    bool handlePacketX11(const NetworkPacket& np);
 #endif
 #if HAVE_WAYLAND
     void setupWaylandIntegration();
-    bool handPackageWayland(const NetworkPackage& np);
+    bool handPacketWayland(const NetworkPacket& np);
 #endif
 
 #if HAVE_X11
@@ -63,7 +63,7 @@ private:
 #endif
     const bool m_x11;
 #if HAVE_WAYLAND
-    KWayland::Client::FakeInput *m_waylandInput;
+    KWayland::Client::FakeInput* m_waylandInput;
     bool m_waylandAuthenticationRequested;
 #endif
 };
