@@ -25,27 +25,25 @@
 
 #include <core/kdeconnectplugin.h>
 
-#define PACKAGE_TYPE_PING QLatin1String("kdeconnect.ping")
+#define PACKET_TYPE_PING QStringLiteral("kdeconnect.ping")
 
-class KDE_EXPORT PingPlugin
+class Q_DECL_EXPORT PingPlugin
     : public KdeConnectPlugin
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.ping")
 
 public:
-    explicit PingPlugin(QObject *parent, const QVariantList &args);
-    virtual ~PingPlugin();
-    
+    explicit PingPlugin(QObject* parent, const QVariantList& args);
+    ~PingPlugin() override;
+
     Q_SCRIPTABLE void sendPing();
     Q_SCRIPTABLE void sendPing(const QString& customMessage);
 
-public Q_SLOTS:
-    virtual bool receivePackage(const NetworkPackage& np);
-    virtual void connected();
+    bool receivePacket(const NetworkPacket& np) override;
+    void connected() override {}
 
-private:
-    QString dbusPath() const;
+    QString dbusPath() const override;
 };
 
 #endif
