@@ -25,7 +25,7 @@
 
 #include <core/kdeconnectplugin.h>
 
-#define PACKAGE_TYPE_MOUSEPAD_REQUEST QStringLiteral("kdeconnect.mousepad.request")
+#define PACKET_TYPE_MOUSEPAD_REQUEST QStringLiteral("kdeconnect.mousepad.request")
 
 class Q_DECL_EXPORT RemoteControlPlugin
     : public KdeConnectPlugin
@@ -34,17 +34,15 @@ class Q_DECL_EXPORT RemoteControlPlugin
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.remotecontrol")
 
 public:
-    explicit RemoteControlPlugin(QObject *parent, const QVariantList &args);
+    explicit RemoteControlPlugin(QObject* parent, const QVariantList &args);
     ~RemoteControlPlugin() override;
 
-    bool receivePackage(const NetworkPackage& /*np*/) override { return false; }
-    void connected() override;
+    bool receivePacket(const NetworkPacket& /*np*/) override { return false; }
+    void connected() override {}
+    QString dbusPath() const override;
 
-    Q_INVOKABLE void moveCursor(const QPoint &p);
-    Q_INVOKABLE void sendCommand(const QString &name, bool val);
-
-private:
-    QString dbusPath() const;
+    Q_SCRIPTABLE void moveCursor(const QPoint &p);
+    Q_SCRIPTABLE void sendCommand(const QString &name, bool val);
 };
 
 #endif
