@@ -23,6 +23,7 @@
 
 #include "kcmplugin/kdeconnectpluginkcm.h"
 
+class QMenu;
 class QStandardItemModel;
 
 class RunCommandConfig
@@ -30,7 +31,7 @@ class RunCommandConfig
 {
     Q_OBJECT
 public:
-    RunCommandConfig(QWidget *parent, const QVariantList&);
+    RunCommandConfig(QWidget* parent, const QVariantList&);
     ~RunCommandConfig() override;
 
 public Q_SLOTS:
@@ -39,11 +40,13 @@ public Q_SLOTS:
     void defaults() override;
 
 private Q_SLOTS:
-    void onDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
+    void onDataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight);
 private:
+    void addSuggestedCommand(QMenu* menu, const QString &name, const QString &command);
+    void insertRow(int i, const QString &name, const QString &command);
     void insertEmptyRow();
 
-    QStandardItemModel *m_entriesModel;
+    QStandardItemModel* m_entriesModel;
 
 };
 
