@@ -36,12 +36,10 @@ class Q_DECL_EXPORT RunCommandPlugin
     Q_OBJECT
 
 public:
-    explicit RunCommandPlugin(QObject *parent, const QVariantList &args);
+    explicit RunCommandPlugin(QObject* parent, const QVariantList& args);
     ~RunCommandPlugin() override;
 
-
-public Q_SLOTS:
-    bool receivePackage(const NetworkPackage& np) override;
+    bool receivePacket(const NetworkPacket& np) override;
     void connected() override;
 
 private Q_SLOTS:
