@@ -25,18 +25,17 @@
 
 #include <core/kdeconnectplugin.h>
 
-class KDE_EXPORT ScreensaverInhibitPlugin
+class Q_DECL_EXPORT ScreensaverInhibitPlugin
     : public KdeConnectPlugin
 {
     Q_OBJECT
 
 public:
-    explicit ScreensaverInhibitPlugin(QObject *parent, const QVariantList &args);
-    virtual ~ScreensaverInhibitPlugin();
+    explicit ScreensaverInhibitPlugin(QObject* parent, const QVariantList& args);
+    ~ScreensaverInhibitPlugin() override;
 
-public Q_SLOTS:
-    virtual bool receivePackage(const NetworkPackage& np);
-    virtual void connected();
+    bool receivePacket(const NetworkPacket& np) override;
+    void connected() override;
 
 private:
     uint inhibitCookie;
