@@ -20,12 +20,14 @@
 
 #include "mounter.h"
 
+#include <unistd.h>
 #include <QDir>
 #include <QDebug>
 
 #include <KLocalizedString>
 
 #include "mountloop.h"
+#include "config-sftp.h"
 #include "sftp_debug.h"
 #include "kdeconnectconfig.h"
 
@@ -37,7 +39,7 @@ Mounter::Mounter(SftpPlugin* sftp)
     , m_started(false)
 {
 
-    connect(m_sftp, &SftpPlugin::packageReceived, this, &Mounter::onPakcageReceived);
+    connect(m_sftp, &SftpPlugin::packetReceived, this, &Mounter::onPakcageReceived);
 
     connect(&m_connectTimer, &QTimer::timeout, this, &Mounter::onMountTimeout);
 
@@ -54,8 +56,7 @@ Mounter::Mounter(SftpPlugin* sftp)
 Mounter::~Mounter()
 {
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "Destroy mounter";
-    //FIXME: We don't unmount becuase it crashes if we try to unmount while the filesystem is being used. Potential memory leak.
-    //unmount();
+    unmount(false);
 }
 
 bool Mounter::wait()
@@ -64,21 +65,21 @@ bool Mounter::wait()
     {
         return true;
     }
-    
+
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "Starting loop to wait for mount";
-    
+
     MountLoop loop;
     connect(this, &Mounter::mounted, &loop, &MountLoop::successed);
     connect(this, &Mounter::failed, &loop, &MountLoop::failed);
     return loop.exec();
 }
 
-void Mounter::onPakcageReceived(const NetworkPackage& np)
+void Mounter::onPakcageReceived(const NetworkPacket& np)
 {
     if (np.get<bool>(QStringLiteral("stop"), false))
     {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "SFTP server stopped";
-        unmount();
+        unmount(false);
         return;
     }
 
@@ -96,9 +97,9 @@ void Mounter::onPakcageReceived(const NetworkPackage& np)
    *    Q_EMIT mounted();
    */
 
-    unmount();
+    unmount(false);
 
-    m_proc = new KProcess(this);
+    m_proc = new KProcess();
     m_proc->setOutputChannelMode(KProcess::MergedChannels);
 
     connect(m_proc, &QProcess::started, this, &Mounter::onStarted);
@@ -113,19 +114,30 @@ void Mounter::onPakcageReceived(const NetworkPackage& np)
     if (np.has(QStringLiteral("multiPaths"))) path = '/';
     else path = np.get<QString>(QStringLiteral("path"));
 
+    QHostAddress addr = m_sftp->device()->getLocalIpAddress();
+    if (addr == QHostAddress::Null) {
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "Device doesn't have a LanDeviceLink, unable to get IP address";
+        return;
+    }
+    QString ip = addr.toString();
+
     const QStringList arguments = QStringList()
         << QStringLiteral("%1@%2:%3").arg(
             np.get<QString>(QStringLiteral("user")),
-            np.get<QString>(QStringLiteral("ip")),
+            ip,
             path)
         << m_mountPoint
         << QStringLiteral("-p") << np.get<QString>(QStringLiteral("port"))
+        << QStringLiteral("-s") // This fixes a bug where file chunks are sent out of order and get corrupted on reception
         << QStringLiteral("-f")
         << QStringLiteral("-F") << QStringLiteral("/dev/null") //Do not use ~/.ssh/config
         << QStringLiteral("-o") << "IdentityFile=" + KdeConnectConfig::instance()->privateKeyPath()
         << QStringLiteral("-o") << QStringLiteral("StrictHostKeyChecking=no") //Do not ask for confirmation because it is not a known host
         << QStringLiteral("-o") << QStringLiteral("UserKnownHostsFile=/dev/null") //Prevent storing as a known host
         << QStringLiteral("-o") << QStringLiteral("HostKeyAlgorithms=ssh-dss") //https://bugs.kde.org/show_bug.cgi?id=351725
+        << QStringLiteral("-o") << QStringLiteral("uid=") + QString::number(getuid())
+        << QStringLiteral("-o") << QStringLiteral("gid=") + QString::number(getgid())
+        << QStringLiteral("-o") << QStringLiteral("ServerAliveInterval=30")
         << QStringLiteral("-o") << QStringLiteral("password_stdin")
         ;
 
@@ -148,11 +160,13 @@ void Mounter::onStarted()
 
     //m_proc->setStandardOutputFile("/tmp/kdeconnect-sftp.out");
     //m_proc->setStandardErrorFile("/tmp/kdeconnect-sftp.err");
-    connect(m_proc, &KProcess::readyReadStandardError, [this]() {
-        qCDebug(KDECONNECT_PLUGIN_SFTP) << "stderr: " << m_proc->readAll();
+
+    auto proc = m_proc;
+    connect(m_proc, &KProcess::readyReadStandardError, [proc]() {
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "stderr: " << proc->readAll();
     });
-    connect(m_proc, &KProcess::readyReadStandardOutput, [this]() {
-        qCDebug(KDECONNECT_PLUGIN_SFTP) << "stdout:" << m_proc->readAll();
+    connect(m_proc, &KProcess::readyReadStandardOutput, [proc]() {
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "stdout:" << proc->readAll();
     });
 }
 
@@ -178,8 +192,8 @@ void Mounter::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "Process failed (exit code:" << exitCode << ")";
         Q_EMIT failed(i18n("Error when accessing to filesystem"));
     }
-    
-    unmount();
+
+    unmount(true);
 }
 
 void Mounter::onMountTimeout()
@@ -190,24 +204,44 @@ void Mounter::onMountTimeout()
 
 void Mounter::start()
 {
-    NetworkPackage np(PACKAGE_TYPE_SFTP_REQUEST, {{"startBrowsing", true}});
-    m_sftp->sendPackage(np);
-    
+    NetworkPacket np(PACKET_TYPE_SFTP_REQUEST, {{"startBrowsing", true}});
+    m_sftp->sendPacket(np);
+
     m_connectTimer.start();
 }
 
-void Mounter::unmount()
+void Mounter::unmount(bool finished)
 {
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "Unmount" << m_proc;
     if (m_proc)
     {
-        auto toDestroy = m_proc;
-        m_proc = nullptr; //So we don't reenter this code path when onFinished gets called
-        toDestroy->kill();
-        delete toDestroy;
+        if (!finished)
+        {
+            //Process is still running, we want to stop it
+            //But when the finished signal come, we might have already gone.
+            //Disconnect everything.
+            m_proc->disconnect();
+            m_proc->kill();
+
+            auto proc = m_proc;
+            m_proc = nullptr;
+            connect(proc, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
+                [proc]() {
+                    qCDebug(KDECONNECT_PLUGIN_SFTP) << "Free" << proc;
+                    proc->deleteLater();
+            });
+            Q_EMIT unmounted();
+        }
+        else
+            m_proc->deleteLater();
+
         //Free mount point (won't always succeed if the path is in use)
+#if defined(HAVE_FUSERMOUNT)
         KProcess::execute(QStringList() << QStringLiteral("fusermount") << QStringLiteral("-u") << m_mountPoint, 10000);
+#else
+        KProcess::execute(QStringList() << QStringLiteral("umount") << m_mountPoint, 10000);
+#endif
+        m_proc = nullptr;
     }
     m_started = false;
 }
-
