@@ -21,29 +21,27 @@
 #ifndef SHARE_CONFIG_H
 #define SHARE_CONFIG_H
 
-#include <kcmodule.h>
-#include <ksharedconfig.h>
+#include "kcmplugin/kdeconnectpluginkcm.h"
 
 namespace Ui {
     class ShareConfigUi;
 }
 
 class ShareConfig
-    : public KCModule
+    : public KdeConnectPluginKcm
 {
     Q_OBJECT
 public:
-    ShareConfig(QWidget *parent, const QVariantList&);
-    virtual ~ShareConfig();
+    ShareConfig(QWidget* parent, const QVariantList&);
+    ~ShareConfig() override;
 
 public Q_SLOTS:
-    virtual void save();
-    virtual void load();
-    virtual void defaults();
+    void save() override;
+    void load() override;
+    void defaults() override;
 
 private:
     Ui::ShareConfigUi* m_ui;
-    KSharedConfigPtr m_cfg;
 
 };
 
